0.9.9 API documentation: GLM_GTX_range

| 0.9.9 API documentation

- Main Page
- Modules
- Files

GLM_GTX_range
Experimental extensions

Include <glm/gtx/range.hpp> to use the features of this extension. More...

## Detailed Description

Include <glm/gtx/range.hpp> to use the features of this extension.

Defines begin and end for vectors and matrices. Useful for range-based for loop. The range is defined over the elements, not over columns or rows (e.g. mat4 has 16 elements).